<?php
	class CI_SKYPE_FORWARDS extends CI_CONFIG
	{
		function get_config_file()
		{
			return CORE_PATH_BASE.'/config/forwarding.xml';
		}

		function save_raw_config($array)
		{
			return parent::save_raw_config($array);
		}

		function set_flag_restart($skype)
		{
			$skypes=array();
			$val=ci_get_core_flag('forwards.restart');
			if ($val) $skypes=split("\n", $val);

			if (in_array('*', $skypes)) return;
			if (in_array($skype, $skypes)) return;
			
			array_push($skypes, $skype);
			ci_set_core_flag('forwards.restart', join("\n", $skypes));
		}

		function get_flag_restart()
		{
			return ci_get_core_flag('forwards.restart');
		}

		function get_rmap($info)
		{
			return array(
				'id'	=> $info['id'],
				'desc'	=> $info['desc'],
				'delay'	=> $info['delay'],
				'skype'	=> array(
					'username'	=> $info['skype_username'],
					'password'	=> $info['skype_password']
				),
				'enabled'	=> $info['enabled'],
				'profile'	=> $info['profile'],
				'destinations' => array(
					'item'	=> split(',', $info['destinations'])
				)
			);
		}

		function get_map($info)
		{
			$info['destinations']['item']=@ci_normalize_xml_array($info['destinations']['item']);
			
			return array(
				'id'					=> $info['id'],
				'desc'					=> $info['desc'],
				'delay'					=> $info['delay'],
				'skype_username'		=> $info['skype']['username'],
				'skype_password'		=> $info['skype']['password'],
				'enabled'				=> $info['enabled'],
				'profile'				=> $info['profile'],
				'destinations'			=> join(',', $info['destinations']['item'])
			);
		}

		function get_info($id)
		{
			$info =& parent::get_info($id);
			if (sizeof($info)) return $info;

			/* Empty (default values) */
			return array(
				'enabled'		=> 'true'
			);
		}

		function get_info_by_username($username)
		{
			$id=$this->search_username($username);
			if (!$id) return array();

			return $this->get_info($id);
		}

		function search_username($username)
		{
			$list =& $this->get_raw_list();
			for ($i=0; $i<sizeof($list); $i++)
			{
				if ($list[$i]['skype']['username'] == $username) return $list[$i]['id'];
			}

			return false;
		}

		function task_delete($id)
		{
			return parent::task_delete($id);
		}

		function task_toggle($id)
		{
			$info =& parent::get_info($id);
			if (!sizeof($info)) return ci_response_ok();
			$this->set_flag_restart($info['skype_username']);
			
			return parent::task_toggle($id);
		}

		function task_reload($id)
		{
			$info =& parent::get_info($id);
			if (!sizeof($info)) return ci_response_ok();

			$this->set_flag_restart($info['skype_username']);
			return ci_response_ok();
		}

		function task_save($info)
		{
			/* Filter params */
			$info['skype_username']=trim(strtolower($info['skype_username']));
			
			/* New item, let's create one ID */
			if (!$info['id'])			$info['id']=md5(uniqid(''));

			if (!$info['skype_username']) return ci_response_error(
					'field',
					array(
						'fieldname' => 'skype_username',
						'desc'		=> ci_lbl('libskype.error.invalid-username')
					)
				);

			/* Validate */
			$foo=$this->search_username($info['skype_username']);
			if ($foo && ($info['id'] != $foo))
				return ci_response_error(
					'field',
					array(
						'fieldname' => 'username',
						'desc'		=> ci_lbl('libskype.error.duplicated-username')
					)
				);

			/* Compose fields */
			$fields=$this->get_rmap($info);

			/* Retrieve item position */
			$n=$this->get_n($info['id']);

			/* Save */
			$list =& $this->get_raw_list();
			$list[$n]=$fields;

			$this->set_flag_restart($info['skype_username']);

			$this->save_raw_config($list);
			return ci_response_ok();
		}
	}
?>